@@ -1,2 +1,2 @@
-def test():
-    print("Py-logging is up!")
\ No newline at end of file
+def testlog():
+    print("Py-logging is up!")
